<template>
  <Popup
    ref="pop"
    :title="title"
    shadow="true"
    showBtn="true"
    @yes="addData"
    @cancel="close"
  >
    <el-form label-width="96px">
      <el-form-item label="数据类型:">
        <el-cascader
          v-model="type"
          :options="dataType"
          :props="{ expandTrigger: 'hover' }"
          :show-all-levels="false"
        ></el-cascader>
      </el-form-item>
    </el-form>
  </Popup>
</template>

<script>
import Popup from "@tools/Popup";
export default {
  name: "SelectData",
  components: {
    Popup,
  },
  data() {
    return {
      title: "添加数据",
      type: "",
      // 数据类型
      dataType: [
        {
          value: "imageLayer",
          label: "影像",
          children: [
            { value: "onlineMap", label: "在线地图" },
            { value: "arcgis", label: "MapServer" },
            { value: "wms", label: "WMS" },
            { value: "wmts", label: "WMTS" },
            { value: "local-map", label: "本地切片服务" },
          ],
        },
        {
          value: "terrainLayer",
          label: "地形",
          children: [
            { value: "sgsterrain", label: "MPT地形" },
            { value: "arcgisterrain", label: "ArcGIS地形" },
            { value: "CesiumGlobeTerrain", label: "CesiumIon全球地形" },
            { value: "terrain", label: "terrain地形" },
          ],
        },
        {
          value: "modelLayer",
          label: "模型",
          children: [
            { value: "b3dm", label: "3DTiles模型" },
            { value: "s3m", label: "S3M模型" },
            { value: "gltf", label: "Gltf模型" },
          ],
        },
        {
          value: "featureLayer",
          label: "矢量",
          children: [
            { value: "kml", label: "KML" },
            { value: "wfs", label: "WFS" },
            { value: "geojson", label: "GeoJOSN" },
            { value: "vector", label: "矢量切片" },
          ],
        },
      ],
    };
  },
  mounted() {},
  methods: {
    // 关闭弹窗
    close() {
      this.$refs.pop.close();
    },
    // 打开弹窗
    open() {
      this.$refs.pop.open();
    },
    // 添加数据
    addData() {
      if (!this.type) {
        this.$message({
          message: "请选择数据类型",
          type: "warning",
        });
        return;
      }
      this.close();
      this.$emit("success", this.type[this.type.length - 1]);
    },
  },
};
</script>

<style scoped lang="less">
.el-form {
  margin-top: 20px;

  /deep/ .el-form-item__label {
    color: #fff;
    font-size: 18px;
  }
}
</style>
